@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2019 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -8,11 +8,11 @@
 //
 // Contributors:
 //   Red Hat, Inc. - initial API and implementation
-//
+
 package exec_info
 
 import (
-	"github.com/eclipse/che-machine-exec/api/model"
+	"github.com/eclipse-che/che-machine-exec/api/model"
 )
 
 // InfoExec - exec to spawn some simple not shell based command
